diff --git a/geomagio/edge/FDSNFactory.py b/geomagio/edge/FDSNFactory.py
index 9de24e5e5f054ad017079ecf8e45a9f84d6c8e83..b72228e87d7201bd645cf1fc2df6c6a7e9123ae9 100644
--- a/geomagio/edge/FDSNFactory.py
+++ b/geomagio/edge/FDSNFactory.py
@@ -25,7 +25,7 @@ from .SNCL import SNCL
 
 
 class FDSNFactory(TimeseriesFactory):
     """TimeseriesFactory for Edge related data.
 
     Parameters
     ----------
@@ -40,22 +40,19 @@ class FDSNFactory(TimeseriesFactory):
     tag: str
         A tag used by edge to log and associate a socket with a given data
         source
-    forceout: bool
-        Tells edge to forceout a packet to miniseed.  Generally used when
-        the user knows no more data is coming.
     observatory: str
         the observatory code for the desired observatory.
     channels: array
         an array of channels {H, D, E, F, Z, MGD, MSD, HGD}.
         Known since channel names are mapped based on interval and type,
-        others are passed through, see #_get_edge_channel().
+        others are passed through, see #_get_fdsn_channel() in FDSNSNCL.py.
     type: {'adjusted', 'definitive', 'quasi-definitive', 'variation'}
         data type
     interval: {'second', 'minute', 'hour', 'day'}
         data interval
-    observatoryMetadata: ObservatoryMetadata object
-        an ObservatoryMetadata object used to replace the default
-        ObservatoryMetadata.
+    variometerMetadata: variometerMetadata object is a variometerMetadata
+        object used to replace the default
+        VariometerMetadata.
     locationCode: str
         the location code for the given edge server, overrides type
         in get_timeseries/put_timeseries
@@ -71,17 +68,14 @@ class FDSNFactory(TimeseriesFactory):
 
     Notes
     -----
-    This is designed to read from any earthworm style waveserver, but it
-        currently only writes to an edge. Edge mimics an earthworm style
-        waveserver close enough that we hope to maintain that compatibility
-        for reading.
+    This is designed to read from the FDSN Client, but it
+        currently only writes to an edge.
     """
 
     def __init__(
         self,
         base_url: str = "http://service.iris.edu",
         tag: str = "GeomagAlg",
-        forceout: bool = False,
         observatory: Optional[str] = None,
         network: str = "NT",
         channels: Optional[List[str]] = None,
@@ -98,7 +92,6 @@ class FDSNFactory(TimeseriesFactory):
         self.Client = FDSNClient(base_url)
         self.remove_sensitivity = remove_sensitivity
         self.tag = tag
-        self.forceout = forceout
         self.interval = interval
         self.observatoryMetadata = variometerMetadata or VariometerMetadata()
         self.network = network
@@ -213,7 +206,9 @@ class FDSNFactory(TimeseriesFactory):
         observatory: str
             observatory code
         channel: str
-            single character channel {H, E, D, Z, F}
+            single character channel {H, E, D, Z, F} unless , {X, Y, Z} is requested
+            in the case they are all channels are returned in a single string and
+            the channels are rotated into a right handed coordinate frame
         type: {'adjusted', 'definitive', 'quasi-definitive', 'variation'}
             data type
         interval: {'second', 'minute', 'hour', 'day'}
@@ -359,7 +354,6 @@ class FDSNFactory(TimeseriesFactory):
         observatory: str
             observatory code
         channel: str
-            edge channel code {MVH, MVE, MVD, ...}
         type: {'adjusted', 'definitive', 'quasi-definitive', 'variation'}
             data type
         interval: {'second', 'minute', 'hour', 'day'}
@@ -25,7 +25,7 @@ from .SNCL import SNCL
 
 class FDSNFactory(TimeseriesFactory):
-    """TimeseriesFactory for Edge related data.
+    """TimeseriesFactory for FDSN related data.
 
     Parameters